#!/usr/bin/env node
import minimist from '../node_modules/minimist/index.mjs';
import { getConfig, createPath } from './feature/defaultConfig.mjs';
import { createCatalog } from './util/createCatalog.mjs';
import { createFile } from './util/createFile.mjs';
import { debugFunction } from './util/debugFunction.mjs';
import { deleteCatalog } from './util/deleteCatalog.mjs';
import { readFile } from './util/readFile.mjs';

const build = async (args) => {
    const config = await getConfig(args);
    debugFunction(config.isDebug, '=== Start SNP BUILD ===');
    return await createCatalog(config.temporaryFolder).then(() => {
        return { ...config };
    });
};
const buildSNP = async (config) => {
    // if (config && config.fileMap && config.fileMap.snpFiles) {
    const snpFiles = config.fileMap?.snpFiles;
    for (const fileName in snpFiles) {
        if (snpFiles.hasOwnProperty(fileName)) {
            const snpFile = snpFiles[fileName];
            const snpTypeFile = ['defaultFile', 'instructionsFile', 'customFile', 'extendFile'];
            const contentFile = {};
            for (const fileType of snpTypeFile) {
                contentFile[fileType] = await readFile(snpFile[fileType]);
            }
            const getContnetToBuild = () => {
                if (contentFile['customFile']) {
                    return contentFile['customFile'];
                }
                if (contentFile['extendFile']) {
                    return contentFile['defaultFile'] + '\n' + contentFile['extendFile'];
                }
                return contentFile['defaultFile'];
            };
            await createFile({
                filePath: createPath([config.projectCatalog, fileName]),
                content: getContnetToBuild(),
                isDebug: config.isDebug,
            });
            console.log(getContnetToBuild());
        }
    }
    return config;
};
const cleanUp = async (config) => {
    debugFunction(config.isDebug, { config }, 'final config');
    await deleteCatalog(config.temporaryFolder, config.isDebug);
    debugFunction(config.isDebug, '=== final SNP BUILD ===');
};
const args = minimist(process.argv.slice(2));
build(args)
    .then((config) => buildSNP(config))
    .then((config) => cleanUp(config));

export { build, buildSNP, cleanUp };
